@@ -1,28 +1,14 @@
-/***************************************************************************
- *   Copyright (C) 2014 by Eike Hein <hein@kde.org>                        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Eike Hein <hein@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "placesmodel.h"
 
 #include <QStandardPaths>
 
 #include <KFilePlacesModel>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 
 PlacesModel::PlacesModel(QObject *parent)
@@ -52,10 +38,8 @@ QHash<int, QByteArray> PlacesModel::roleNames() const
 
 bool PlacesModel::activityLinkingEnabled() const
 {
-    QVector<KPluginMetaData> jsonPlugins = KPluginLoader::findPlugins("kf5/kfileitemaction", [](const KPluginMetaData &metaData) {
-        return metaData.pluginId() == QStringLiteral("kactivitymanagerd_fileitem_linking_plugin");
-    });
-    return !jsonPlugins.isEmpty();
+    KPluginMetaData plugin = KPluginMetaData::findPluginById("kf5/kfileitemaction", QStringLiteral("kactivitymanagerd_fileitem_linking_plugin"));
+    return plugin.isValid();
 }
 
 bool PlacesModel::showDesktopEntry() const
